#
# spec file for package sratom
#
# Copyright (c) 2023 SUSE LLC
# Copyright (c) 2025 Andreas Stieger <Andreas.Stieger@gmx.de>
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define sover 0
Name:           sratom
Version:        0.6.18
Release:        1.1
Summary:        A library for serialising LV2 atoms to/from RDF
License:        ISC
Group:          Development/Libraries/C and C++
URL:            https://drobilla.net/software/sratom.html
Source0:        https://download.drobilla.net/sratom-%{version}.tar.xz
Source1:        baselibs.conf
BuildRequires:  doxygen
BuildRequires:  graphviz
BuildRequires:  meson
BuildRequires:  pkgconfig
BuildRequires:  pkgconfig(lv2) >= 1.18.4
BuildRequires:  pkgconfig(serd-0) >= 0.30.10
BuildRequires:  pkgconfig(sord-0) >= 0.16.16

%description
A library for serialising LV2 atoms to/from RDF, particularly the Turtle syntax.

%package        -n libsratom-0-%{sover}
Summary:        A library for serialising LV2 atoms to/from RDF
Group:          System/Libraries

%description    -n libsratom-0-%{sover}
A library for serialising LV2 atoms to/from RDF, particularly the Turtle syntax.

%package        devel
Summary:        Development files for libsratom
Group:          Development/Libraries/C and C++
Requires:       libsratom-0-%{sover} = %{version}
Provides:       libsratom-0-devel = %{version}
Obsoletes:      libsratom-0-devel < %{version}

%description    devel
Development files for libsratom.

%prep
%autosetup -p1

%build
%meson -Ddocs=disabled
%meson_build

%install
%meson_install

%ldconfig_scriptlets -n libsratom-0-%{sover}

%files -n libsratom-0-%{sover}
%license COPYING
%doc NEWS
%{_libdir}/libsratom-0.so.%{sover}*

%files devel
%license COPYING
%{_libdir}/libsratom-0.so
%{_includedir}/sratom-0/
%{_libdir}/pkgconfig/sratom-0.pc

%changelog
* Mon Mar 10 2025 Andreas Stieger <andreas.stieger@gmx.de>
- update to 0.6.18:
  * Avoid snprintf when writing MIDI events
  * developer visible code fixes
- includes changes from 0.6.16:
  * Constrain relative URI references to the base URI
  * maintenance and clean-up of build system
* Sun Sep 10 2023 Luigi Baldoni <aloisio@gmx.com>
- Updated versions for buildtime requirements
* Mon Dec 26 2022 Konstantin Voinov <kv@kott.no-ip.biz>
- Switch to meson
- Update to 0.6.14
  * Add project metadata
  * Adopt REUSE machine-readable licensing standard
  0.6.12 changes:
  * Switch to meson build system
* Sat Jun 18 2022 Dirk Müller <dmueller@suse.com>
- update to 0.6.10:
  * Fix documentation installation directory
  * Fix potential blank node ID truncation
- drop fix-FORTIFY_SOURCE3.patch: obsolete
* Tue Apr 12 2022 Martin Liška <mliska@suse.cz>
- Add fix-FORTIFY_SOURCE3.patch that is suggested to upstream:
  gh#lv2/sratom#6
* Mon Mar  8 2021 Dirk Müller <dmueller@suse.com>
- update to 0.6.8:
  * Fix potential null pointer dereference
- disable docs from building: only in -devel package
* Mon Oct 26 2020 Dirk Mueller <dmueller@suse.com>
- update to 0.6.6:
  * Fix various minor warnings and other code quality issues
* Wed May 27 2020 Giordano Boschetti <geekosdaw@gmail.com>
- Updated to 0.6.4
* Fri Sep 21 2018 olaf@aepfle.de
- Use -std=gnu99 to fix compilation of bogus C code
* Fri Aug 24 2018 tchvatal@suse.com
- Update to 0.6.2:
  * Update waf internals to work with python 3.7
* Thu Nov  2 2017 mpluskal@suse.com
- Update to version 0.6.0:
  * Add sratom_set_env() for setting prefixes
  * Fix padding of constructed vectors (thanks Hanspeter Portner)
  * Support round-trip serialisation of relative paths
  * Support sequences with beat time stamps
  * Fix warnings when building with ISO C++ compilers
  * Upgrade to waf 1.8.14
- Run spec-cleaner
- Use python3
- Run tests during build
* Mon Jan 30 2017 jengelh@inai.de
- Fix mismatching RPM group
- Rename soname macro to sover as it does not contain a name
* Thu Jan 12 2017 olaf@aepfle.de
- Add baselibs.conf for gstreamer-plugins-bad-32bit
* Thu Mar 26 2015 p.drouand@gmail.com
- Update to version 0.4.6
  * Update for latest LV2 Atom Object simplification
  * Don't set eg prefix in sratom_to_turtle
  * Upgrade to waf 1.7.16
* Fri Jul 11 2014 reddwarf@opensuse.org
- Update to 0.4.4
  * Escape invalid characters when writing paths as URIs
  * Fancier printing without subject and predicate
* Thu Sep  5 2013 reddwarf@opensuse.org
- Update to 0.4.2
  * Fix serialisation of nested tuples
  * Fix memory leaks
  * Use new sord API to clean up and shrink code
  * Disable timestamps in HTML documentation for reproducible build
  * Update to waf 1.7.9 and autowaf r90 (install docs to versioned directory)
- Remove sratom-0.4.0-build_compare.patch, applied upstream
- The minimum serd version is now 0.12.0
- The documentation directory is now versioned
* Sun Aug 26 2012 reddwarf@opensuse.org
- Update to 0.4.0
  * Correctly read objects with several rdf:type properties
  * Support writing Object Atoms as top level descriptions if
    subject and predicate are not given.
  * Fix various hyper-strict warnings
  * Upgrade to waf 1.7.2
- Add sratom-0.4.0-build_compare.patch to make build reproducible
* Thu Aug  9 2012 reddwarf@opensuse.org
- First version of the package
